import {useEffect, useState} from 'react';
import './home.css';
import {
    Button,
} from "@fluentui/react-components";
import {
    CloudAddFilled, DismissRegular
} from "@fluentui/react-icons";
import {useNavigate} from "react-router-dom";
import {Dial} from "../../api";
import {useToast} from "../../message";
import {Connection} from "../../interfaces/connection";

function Home() {
    const {dispatchMessage} = useToast();
    const [connectionFilterKeywords, setConnectionFilterKeywords] = useState<string>('');
    const navigate = useNavigate();
    const [connectionList, setConnectionList] = useState<Connection[]>([]);

    useEffect(() => {
        Dial<{ list: Connection[] }>("/api/connection/list").then(res => {
            dispatchMessage(res.msg, res.status === 200 ? "success" : "error");
            if (res.status === 200) {
                setConnectionList(res.data.list)
            }
        })
    }, []);

    async function handleConnect(item: Connection) {
        console.log('[DEBUG] db click item =', item)
        for (const c of connectionList) {
            if(c.active) {
                return
            }
        }

        let res = await Dial("/api/connection/connect", {id: item.id})
        if (res.status === 200) {
            dispatchMessage("连接成功", "success")
            for (const c of connectionList) {
                c.active = c.id === item.id;
            }
        }
    }

    return (
        <div className="container">
            <div className="header">
                <Button appearance="primary" icon={<CloudAddFilled/>} onClick={() => {
                    navigate("/connection")
                }}>
                    新建连接
                </Button>
            </div>
            <div className="body">
                <div className="body-connections">
                    <div className="body-connections-search">
                        <input className="body-connections-search-input" type={"text"} placeholder="搜索连接"
                               value={connectionFilterKeywords}
                               onChange={(e) => setConnectionFilterKeywords(e.target.value)}/>
                        <div className="body-connections-search-dismiss" onClick={() => {
                            setConnectionFilterKeywords('')
                        }}>
                            <DismissRegular/>
                        </div>
                    </div>
                    <div className="body-connections-list">
                        {connectionList.map(item => {
                            return <div key={item.id} className={item.active?'body-connections-list-item active':'body-connections-list-item'}>
                                <button onDoubleClick={() => handleConnect(item)}
                                        className='body-connections-list-item-button'>{item.name}</button>
                            </div>
                        })}
                    </div>
                </div>
                <div className="body-content"></div>
            </div>
            <div className="footer"></div>
        </div>
    )
}

export default Home
